package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.service.BaseService;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

/**
 * 用户公共API
 *
 * @author : Charles
 * @date : 2021/3/4
 */
@Api(tags="用户公共API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user")
public class BaseApi {

    private final BaseService baseService;
    @Value(value = "${swagger.enabled}")
    private Boolean swaggerEnabled;

    @GetMapping({"", "/"})
    public String welcome(){
        if (swaggerEnabled){
            return "欢迎使用！<br><a href='http://47.119.112.46:18011/doc.html'>doc接口文档入口(beta)</a><br><a href='http://47.119.112.46:18011/swagger-ui/index.html'>swagger接口文档入口(beta)</a>";
        }
        return "欢迎使用！";
    }

    /**
     * 获取图片验证码
     *
     * spi旧接口：/user/getImgVerifyCode
     *
     * @param platformType 0:www，1:crm/h5，2:小程序
     */
    @ApiOperation("获取图片验证码")
    @ApiImplicitParam(required = true, name = "platformType", value = "0:www，1:crm/h5，2:小程序")
    @GetMapping("/captcha")
    public ResponseJson<Map<String, Object>> getCaptchaImage(Integer platformType) {
        return baseService.getCaptchaImage(platformType);
    }

    /**
     * 获取短信验证码
     *
     * spi旧接口：/user/activateCodeByReg
     *
     * @param mobile           手机号
     * @param activateCodeType 1:找回密码,2:手机号注册机构,3:供应商注册
     * @param imgCode          图片验证码
     * @param token            图片验证码token
     * @param platformType     0:www，1:crm/h5，2:小程序
     */
    @ApiOperation("获取短信验证码")
    @ApiImplicitParams({
        @ApiImplicitParam(required = true, name = "mobile", value = "手机号"),
        @ApiImplicitParam(required = true, name = "activateCodeType", value = "1:找回密码,2:手机号注册机构,3:供应商注册"),
        @ApiImplicitParam(required = true, name = "imgCode", value = "图片验证码"),
        @ApiImplicitParam(required = true, name = "token", value = "图片token"),
        @ApiImplicitParam(required = true, name = "platformType", value = "0:www，1:crm/h5，2:小程序")
    })
    @GetMapping("/sms/code")
    public ResponseJson getSmsCode(String mobile, String activateCodeType, String imgCode, String token, Integer platformType) {
        return baseService.getSmsCode(mobile, activateCodeType, imgCode, token, platformType);
    }


}
